<h2 align="center">junky lib: PyTorch utilites</h2>

[![PyPI Version](https://img.shields.io/pypi/v/junky?color=blue)](https://pypi.org/project/junky/)
[![Python Version](https://img.shields.io/pypi/pyversions/junky?color=blue)](https://www.python.org/)
[![License: BSD-3](https://img.shields.io/badge/License-BSD-brightgreen.svg)](https://opensource.org/licenses/BSD-3-Clause)

Provides a bunch of tools and utilites to use with PyTorch.

## Installation

### pip

***junky*** supports *Python 3.5* or later. To install it via *pip*, run:
```sh
$ pip install junky
```

If you currently have a previous version of ***junky*** installed, use:
```sh
$ pip install junky -U
```

### From Source

Alternatively, you can also install ***junky*** from source of this *git
repository*:
```sh
$ git clone https://github.com/fostroll/junky.git
$ cd junky
$ pip install -e .
```

## License

***junky*** is released under the BSD License. See the
[LICENSE](https://github.com/fostroll/junky/blob/master/LICENSE) file for more
details.
